Macro html_to_string_macro::html [−][src]
html!() { /* proc-macro */ }Expand description
Converts HTML to String
This macro should only be used from the yate crate, not directly, as
things will break otherwise.
html!() { /* proc-macro */ }Converts HTML to String
This macro should only be used from the yate crate, not directly, as
things will break otherwise.