Macro html_to_string_macro::html [−][src]
html!() { /* proc-macro */ }Expand description
Converts HTML to String
Embedded Rust code in braced blocks must return something that implements
std::fmt::Display. More information about supported syntax can be found here.